@@ -88,7 +88,7 @@ op_test_resolve_names ()
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, NULL, NULL);
+	cnc = e_ews_connection_new (uri, username, password, TRUE, NULL, NULL, NULL);
 	g_assert (cnc != NULL);
 	e_ews_connection_resolve_names_start	(cnc, EWS_PRIORITY_MEDIUM, username,
 						 EWS_SEARCH_AD, NULL, FALSE, resolve_names_cb,
